#include "gpib.h"
#include "formatio.h"
#include "ax2320.h"

#define AX2320_REVISION   "A1.0"

/*= AX2320/AX1320 Metrix ==================================================*/
/* LabWindows CVI 3.1 Instrument Driver                                    */
/* Original Release:  02/15/96                                             */
/* By: Francis VALOTEAU                                                    */
/*     Ph : 50 33 62 62       Fax : 50 33 62 71                            */
/*  Originally written in C                                                */
/* Modification History: None                                              */
/*=========================================================================*/

/*= INSTRUMENT TABLE ======================================================*/
/* address array: contains the GPIB addresses of opened instruments.       */
/* bd array: contains the device descriptors returned by OpenDev.          */
/* instr_cnt: contains the number of instruments open of this model type.  */
/*=========================================================================*/
static short address[AX2320_MAX_INSTR + 1];
static short bd[AX2320_MAX_INSTR + 1];
static short instr_cnt;

/*= STATIC VARIABLES ======================================================*/
static char   cmd[50];       /* buffer for GPIB I/O strings              */
static short  ax2320_err;    /* error variable for the instrument module */
static short  ax2320_model;  /* Model of power supply                    */

/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS ===================================*/
static char *read_v[1 + 1];       /* Read voltage query                  */
static char *read_i[1 + 1];       /* Read current query                  */
static char *error_label[4 + 1];  /* Error message					     */

/*= UTILITY ROUTINES ======================================================*/
short ax2320_open_instr (short, short *);
short ax2320_close_instr (short);
short ax2320_invalid_integer_range (short, short, short, short);
short ax2320_invalid_longint_range (long, long, long, short);
short ax2320_invalid_real_range (double , double , double , short);
short ax2320_device_closed (short);
short ax2320_read_data (short, char *, short);
short ax2320_write_data (short , char *, short);
short ax2320_read_data_file (short, char *);
short ax2320_write_data_file (short, char *);
short ax2320_poll (short, char *);
short ax2320_set_timeout (short , short, short *);
void ax2320_setup_arrays (void);

/*=========================================================================*/
/* Function: Initialize                                                    */
/* Purpose:  This function opens the instrument, queries the instrument    */
/*           for its ID, and initializes the instrument to a known state.  */
/*=========================================================================*/
short ax2320_init (short addr, short id_query, short rest, short *instrID)
{
    short  ID,error;

    if (ax2320_invalid_integer_range (addr, 0, 30, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (id_query, 0, 1, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (rest, 0, 1, -3) != 0)
        return ax2320_err;

    if (ax2320_open_instr (addr, &ID) != 0)
        return ax2320_err;

    /* Set Time-out to 10 S */
    if (ax2320_set_timeout (ID, 13, &error))
        return ax2320_err;

    if (id_query) {
        if (ax2320_write_data (ID, "MODEL?", 6) != 0) {
            ax2320_close_instr (ID);
            return ax2320_err;
        }
        if (ax2320_read_data (ID, cmd, 50) != 0) {
            ax2320_close_instr (ID);
            return ax2320_err;
        }
        Scan (cmd, "2320");
        if (NumFmtdBytes () != 4)  {
            Scan (cmd, "1320");
            if (NumFmtdBytes () != 4)  {
                ax2320_err = 223;
                ax2320_close_instr (ID);
                return ax2320_err;
            }
            else ax2320_model=1320;
        }
        else ax2320_model=2320;
    }

    if (rest) {
        if (ibclr (bd[ID])&0x8000) {
            ax2320_close_instr (ID);
            ax2320_err=224;
            return ax2320_err;
        }
        if (ax2320_model==2320)
            Fmt (cmd, "%s<TRACK 0\nOUT1 0\nOUT2 0\nOCP 0");
        else
            Fmt (cmd, "%s<OUT 0\nOUT 0\nOCP 0");

        if (ax2320_write_data (ID,cmd, NumFmtdBytes ()) != 0) {
            ax2320_close_instr (ID);
            return ax2320_err;
        }
    }
    /* Initialize arrays */
    ax2320_setup_arrays ();
    *instrID = ID;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Set Mode (OUT or OUT1 or OUT2 ,TRK,OCP)                       */
/* Purpose:  This function set the mode Tracking (ON or OFF)               */
/*=========================================================================*/
short ax2320_set_mode (short instrID,short ch1 ,short ch2 ,short tracking ,short ocp)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (ch1, 0, 1, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (ch2, 0, 1, -3) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (tracking, 0, 1, -4) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (ocp, 0, 1, -5) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "%s<OUT %d\nOCP %d",ch1,ocp);
    else
        Fmt (cmd, "%s<TRACK %d\nOUT1 %d\nOUT2 %d\nOCP %d",tracking,ch1,ch2,ocp);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Set Output Voltage (VSET)                                     */
/* Purpose:  This function set the output voltage for CH1 or CH2 (AX2320)  */
/*=========================================================================*/
short ax2320_set_voltage (short instrID, short channel, double voltage )
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (channel, 1, 2, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_real_range (voltage, 0.0 ,32.05, -3) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "VSET %f\n", voltage);
    else
        Fmt (cmd, "VSET%d %f\n", channel, voltage);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Set Output Current (ISET)                                     */
/* Purpose:  This function set the output current for CH1 or CH2 (AX2320)  */
/*=========================================================================*/
short ax2320_set_current (short instrID, short channel, double current )
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (channel, 1, 2, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_real_range (current, 0.0 ,2.05, -3) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "ISET %f\n", current);
    else
        Fmt (cmd, "ISET%d %f\n", channel, current);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Set Overvoltage (OVSET)                                       */
/* Purpose:  This function set the overvoltage for CH1 or CH2 (AX2320)     */
/*=========================================================================*/
short ax2320_set_over_voltage (short instrID, short channel, double over_voltage )
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (channel, 1, 2, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_real_range (over_voltage, 0.0 ,35.1, -3) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "OVSET %f\n", over_voltage);
    else
        Fmt (cmd, "OVSET%d %f\n", channel, over_voltage);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Read Voltage                                                  */
/* Purpose:  This function reads the set and output voltage                */
/*           of CH1 or CH2 (AX2320)                                        */
/*=========================================================================*/
short ax2320_read_voltage (short instrID, short channel, short type, double *voltage)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (channel, 1, 2, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (type, 0 ,1, -3) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "%s<%s?", read_v[type]);
    else
        Fmt (cmd, "%s<%s%d?", read_v[type], channel);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;
    if (ax2320_read_data (instrID, cmd, 50) != 0)
        return ax2320_err;

    Fmt (voltage,"%f<%s",cmd);
    return ax2320_err;
}
/*=========================================================================*/
/* Function: Read Current                                                  */
/* Purpose:  This function reads the set and output current                */
/*           of CH1 or CH2 (AX2320)                                        */
/*=========================================================================*/
short ax2320_read_current (short instrID, short channel, short type, double *current)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (channel, 1, 2, -2) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (type, 0 ,1, -3) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "%s<%s?", read_i[type]);
    else
        Fmt (cmd, "%s<%s%d?", read_i[type], channel);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;
    if (ax2320_read_data (instrID, cmd, 50) != 0)
        return ax2320_err;
    Fmt (current,"%f<%s",cmd);

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Read Overvoltage                                              */
/* Purpose:  This function reads the overvoltage of CH1 or CH2 (AX2320)    */
/*=========================================================================*/
short ax2320_read_over_voltage (short instrID, short channel, double *over_voltage)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_invalid_integer_range (channel, 1, 2, -2) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    if (ax2320_model==1320)
        Fmt (cmd, "%s<OVSET?");
    else
        Fmt (cmd, "%s<OVSET%d?", channel);

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;
    if (ax2320_read_data (instrID, cmd, 50) != 0)
        return ax2320_err;
    Fmt (over_voltage,"%f<%s",cmd);

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Write To Instrument                                           */
/* Purpose:  This function writes a command string to the instrument.      */
/*=========================================================================*/
short ax2320_write (short instrID, char *cmd_string)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_device_closed(instrID) != 0)
        return ax2320_err;

    Fmt (cmd, "%s<%s", cmd_string);
    if (ax2320_write_data (instrID, cmd, NumFmtdBytes()) != 0)
        return ax2320_err;

    return ax2320_err;
}

/*=========================================================================*/
/* Function: Read Instrument Buffer                                        */
/* Purpose:  This function reads the output buffer of the instrument.      */
/*=========================================================================*/
short ax2320_read (short instrID, short numbytes, char *in_buff, short *bytes_read)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_device_closed(instrID) != 0)
        return ax2320_err;

    *bytes_read = 0;
    if (ax2320_read_data (instrID, in_buff, numbytes) != 0)
        return ax2320_err;

    *bytes_read = ibcnt;

    return ax2320_err;
}

/*=========================================================================*/
/* Function: Reset                                                         */
/* Purpose:  This function resets the instrument.                          */
/*=========================================================================*/
short ax2320_reset (short instrID)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_device_closed(instrID) != 0)
        return ax2320_err;

    if (ibclr (bd[instrID])&0x8000) {
        ax2320_err=224;
        return ax2320_err;
    }
    if (ax2320_model==2320)
        Fmt (cmd, "%s<TRACK 0\nOUT1 0\nOUT2 0\nOCP 0");
    else
        Fmt (cmd, "%s<OUT 0\nOUT 0\nOCP 0");

    if (ax2320_write_data (instrID,cmd, NumFmtdBytes ()) != 0)
        return ax2320_err;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Error Query                                                   */
/* Purpose:  This function queries the instrument error queue.             */
/*=========================================================================*/
short ax2320_error_query (short instrID, short *error, char *error_message)
{
    long numero_err;
    
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_device_closed(instrID) != 0)
        return ax2320_err;

   FillBytes(cmd,0,50,0);
   if (ax2320_write_data (instrID, "ERROR?", 6) != 0)
        return ax2320_err;
    if (ax2320_read_data (instrID, cmd, 50) != 0)
        return ax2320_err;

	Scan (cmd, "%s>%i", &numero_err);
	*error=(short)numero_err;
	Fmt (error_message, "%s<%s", error_label[*error]);
    return ax2320_err;
}
/*=========================================================================*/
/* Function: Revision                                                      */
/* Purpose:  This function returns the driver and instrument revisions.    */
/*=========================================================================*/
short ax2320_revision_query (short instrID, char *driver_rev, char *instr_rev)
{
    short index;

    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;
    if (ax2320_device_closed(instrID) != 0)
        return ax2320_err;

    FillBytes (cmd, 0, 50, 0);
    if (ax2320_write_data (instrID, "MODEL?", 6) != 0)
        return ax2320_err;
    if (ax2320_read_data (instrID, cmd, 50) != 0)
        return ax2320_err;

    Scan (cmd, "2320");
    if (NumFmtdBytes () != 4)  {
        Scan (cmd, "1320");
        if (NumFmtdBytes () != 4)  {
            ax2320_err = 236;
            return ax2320_err;
        }
    }
    Fmt (instr_rev,"%s<%s",cmd);
    Fmt (driver_rev, "%s<%s", AX2320_REVISION);

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Close                                                         */
/* Purpose:  This function closes the instrument.                          */
/*=========================================================================*/
short ax2320_close (short instrID)
{
    if (ax2320_invalid_integer_range (instrID, 1, AX2320_MAX_INSTR, -1) != 0)
        return ax2320_err;

    if (ax2320_device_closed (instrID))
        return ax2320_err;

    ax2320_close_instr (instrID);
    return ax2320_err;
}
/*= UTILITY ROUTINES ======================================================*/

/*=========================================================================*/
/* Function: Open Instrument                                               */
/* Purpose:  This function locates and initializes an entry in the         */
/*           Instrument Table and the GPIB device table for the            */
/*           instrument.  If successful, the instrument ID is returned,    */
/*           else a -1 is returned.  The size of the Instrument Table can  */
/*           be changed in the include file by altering the constant       */
/*           AX2320_MAX_INSTR.                                             */
/*=========================================================================*/
short ax2320_open_instr (short addr, short *ID)
{
    short i, instrID;

    instrID = 0;
    ax2320_err=0;

/* Check to see if the instrument is already in the Instrument Table. */

    for (i=1; i<= AX2320_MAX_INSTR; i++)
        if (address[i] == addr) {
            instrID = i;
            i = AX2320_MAX_INSTR;
         }

/* If it is not in the instrument table, open an entry for the instrument. */

    if (instrID <= 0)
        for (i=1; i<= AX2320_MAX_INSTR; i++)
            if (address[i] == 0) {
                instrID = i;
                i = AX2320_MAX_INSTR;
             }

/* If an entry could not be opened in the Instrument Table, return an error.*/

    if (instrID <= 0) {
        ax2320_err = 220;
        return ax2320_err;
     }

/*  If the device has not been opened in the GPIB device table (bd[ID] = 0),*/
/*  then open it.                                                           */

    if (bd[instrID] <= 0)    {
        if (instr_cnt <= 0)
            CloseInstrDevs("ax2320");
        bd[instrID] = OpenDev ("", "ax2320");
        if (bd[instrID] <= 0)    {
            ax2320_err = 220;
            return ax2320_err;
        }
        instr_cnt += 1;
        address[instrID] = addr;
     }

/*  Change the primary address of the device    */

    if (ibpad (bd[instrID], addr) < 0)   {
        ax2320_err = 233;
        return ax2320_err;
    }
    *ID = instrID;
    return ax2320_err;
}
/*=========================================================================*/
/* Function: Close Instrument                                              */
/* Purpose:  This function closes the instrument by removing it from the   */
/*           GPIB device table and setting the address and the bd to zero  */
/*           in the Instrument Table.  The return value is equal to the    */
/*           global error variable.                                        */
/*=========================================================================*/
short ax2320_close_instr (short instrID)
{
    if (bd[instrID] != 0) {
        CloseDev (bd[instrID]);
        bd[instrID] = 0;
        address[instrID] = 0;
        instr_cnt -= 1;
     }
    else
        ax2320_err = 221;

    return ax2320_err;
 }
/*=========================================================================*/
/* Function: Invalid Integer Range                                         */
/* Purpose:  This function checks an integer to see if it lies between a   */
/*           minimum and maximum value.  If the value is out of range, set */
/*           the global error variable to the value err_code.  If the      */
/*           value is OK, error = 0.                                       */
/*=========================================================================*/
short ax2320_invalid_integer_range (short val, short min, short max, short err_code)
{
    if ((val < min) || (val > max))
        ax2320_err = err_code;
    else
        ax2320_err = 0;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Invalid Long Integer Range                                    */
/* Purpose:  This function checks a long integer to see if it lies between */
/*           a minimum and maximum value.  If the value is out of range,   */
/*           set the global error variable to the value err_code.  If the  */
/*           value is OK, error = 0.  The return value is equal to the     */
/*           global error value.                                           */
/*=========================================================================*/
short ax2320_invalid_longint_range (long val, long min, long max, short err_code)
{
    if (val < min || val > max)
        ax2320_err = err_code;
    else
        ax2320_err = 0;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Invalid Real Range                                            */
/* Purpose:  This function checks a real number to see if it lies between  */
/*           a minimum and maximum value.  If the value is out of range,   */
/*           set the global error variable to the value err_code.  If the  */
/*           value is OK, error = 0.                                       */
/*=========================================================================*/
short ax2320_invalid_real_range (double val, double min, double max, short err_code)
{
    if ((val < min) || (val > max))
        ax2320_err = err_code;
    else
        ax2320_err = 0;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Device Closed                                                 */
/* Purpose:  This function checks to see if the module has been            */
/*           initialized.  If the device has not been opened, a 1 is       */
/*           returned, 0 otherwise.                                        */
/*=========================================================================*/
short ax2320_device_closed (short instrID)
{
    if (bd[instrID] <= 0)
        ax2320_err = 232;
    else
        ax2320_err = 0;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Read Data                                                     */
/* Purpose:  This function reads a buffer of data from the instrument. The */
/*           return value is equal to the global error variable.           */
/*=========================================================================*/
short ax2320_read_data (short instrID, char *buf, short cnt)
{
    if (ibrd (bd[instrID], buf, (long)cnt) & 0x8000)
        ax2320_err = 231;
    else
        ax2320_err = 0;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Write Data                                                    */
/* Purpose:  This function writes a buffer of data to the instrument. The  */
/*           return value is equal to the global error variable.           */
/*=========================================================================*/
short ax2320_write_data (short instrID, char *buf, short cnt)
{
    if (ibwrt (bd[instrID], buf, (long)cnt) & 0x8000)
        ax2320_err = 230;
    else
        {
        /* WARNING : BUG IN AX : the power supply returns two bytes      */
        /* after each commands (without ?) sent to it (0x0D and 0x0A).   */
        /* The driver has to read those two bytes before sending any     */
        /* other commands (if not, error IEEE ===> 230)                  */
        if (FindPattern (buf, 0, -1, "?", 0, 0)==-1) {
            if (ax2320_read_data (instrID, cmd, 50)!=0)
                return ax2320_err;
        }
        else
            ax2320_err = 0;
        }
    return ax2320_err;
}
/*=========================================================================*/
/* Function: Read Data File                                                */
/* Purpose:  This function reads a buffer of data from the instrument and  */
/*           stores it to the file specified by "filename".  Filename must */
/*           either be a string, such as "C:\\lw\\instr\\file" or a pointer*/
/*           to such a string.  The return value is equal to the global    */
/*           error variable.                                               */
/*=========================================================================*/
short ax2320_read_data_file (short instrID, char *filename)
{
    if (ibrdf (bd[instrID], filename) & 0x8000)
        ax2320_err = 229;
    else
        ax2320_err = 0;

    return ax2320_err;
}

/*=========================================================================*/
/* Function: Write Data File                                               */
/* Purpose:  This function writes a buffer of data from the file specified */
/*           by "filename" to the instrument. Filename must either be a    */
/*           string, such as "C:\\lw\\instr\\file" or a pointer to such a  */
/*           string.  The return value is equal to the global error        */
/*           variable.                                                     */
/*=========================================================================*/
short ax2320_write_data_file (short instrID, char *filename)
{
    if (ibwrtf (bd[instrID], filename) & 0x8000)
        ax2320_err = 228;
    else
        ax2320_err = 0;

    return ax2320_err;
}

/*=========================================================================*/
/* Function: Serial Poll                                                   */
/* Purpose:  This function performs a serial poll on the instrument.       */
/*           The status byte of the instrument is placed in the response   */
/*           variable. The return value is equal to the global error       */
/*           variable.                                                     */
/*=========================================================================*/
short ax2320_poll (short instrID, char *response)
{
    if (ibrsp (bd[instrID], response) & 0x8000)
        ax2320_err = 226;
    else
        ax2320_err = 0;

    return ax2320_err;
}

/*=========================================================================*/
/* Function: Set Timeout                                                   */
/* Purpose:  This function changes or disables the timeout of the device.  */
/*           Refer to the LabWindows Standard Libraries Reference Manual   */
/*           for timeout codes.                                            */
/*=========================================================================*/
short ax2320_set_timeout (short instrID, short tmo_code, short *old_timeout)
{
    if (ibtmo (bd[instrID], tmo_code) & 0x8000)
        ax2320_err = 239;
    else
        ax2320_err = 0;

    return ax2320_err;
}
/*=========================================================================*/
/* Function: Setup Arrays                                                  */
/* Purpose:  This function is called by the init routine to initialize     */
/*           global arrays.                                                */
/*           This routine should be modified for each instrument to        */
/*           include instrument-dependent commmand arrays.                 */
/*=========================================================================*/
void ax2320_setup_arrays ()
{
    read_v[0] 		= "VSET";
    read_v[1] 		= "VOUT";
    read_i[0] 		= "ISET";
    read_i[1] 		= "IOUT";
	error_label[0]  = "No Error.";
	error_label[1]  = "Command String Error.";
	error_label[2]  = "Numeric String Out of Range.";
	error_label[3]  = "Numeric String Over Length.";
	error_label[4]  = "Command Sequence Error.";
}
/*= THE END ===============================================================*/
